@@ -243,7 +243,8 @@ class Link(object):
 
 #: A class that holds all the properties for media files
 Media = collections.namedtuple('Media', ['relative_margins', 'filename', 'autoplay', 'repeat', 'poster',
-                                         'show_controls'], defaults=[False, False, False, False])
+                                         'show_controls', 'type', 'start_pos', 'duration'],
+                               defaults=[False, False, False, False, '', 0., 0.])
 
 
 class Page(object):
@@ -323,6 +324,8 @@ class Page(object):
                 movie_options = {'show_controls': movie.show_controls(), 'poster': movie.need_poster()}
                 try:
                     movie_options['repeat'] = movie.get_play_mode() == Poppler.MoviePlayMode.REPEAT
+                    movie_options['start_pos'] = movie.get_start() / 1e9
+                    movie_options['duration'] = movie.get_duration() / 1e9
                     # NB: autoplay not part of Poppler’s MovieActivationParameters struct
                 except AttributeError:
                     pass  # Missing functions in pre-21.04 Poppler versions
@@ -500,7 +503,7 @@ class Page(object):
             relative_margins.y1 = rect.y1 / self.ph        # bottom
             relative_margins.y2 = 1.0 - rect.y2 / self.ph  # top
 
-            media_options = {}
+            media_options = {'type': media.get_mime_type()}
             try:
                 media_options['autoplay'] = media.get_auto_play()
                 media_options['show_controls'] = media.get_show_controls()
@@ -1051,6 +1054,20 @@ class Document(object):
         return self.doc_page_labels != [str(n + 1) for n in range(self.nb_pages)]
 
 
+    def get_last_label_pages(self):
+        """ Return the last page number for each consecutively distinct page label
+
+        In other words, squash together consecutive same labels
+        """
+        last = None
+        pages = []
+        for page, label in enumerate(self.page_labels):
+            if label != last:
+                pages.append(page)
+            last = label
+        return pages
+
+
     def lookup_label(self, label, prefix_unique=True):
         """ Find a page from its label.
 
@@ -1077,8 +1094,8 @@ class Document(object):
             pass
 
         # try case-insensitive match, prefix case-sensitive match, prefix case-insensitive match (unless prefix_unique)
-        full = len(label)
-        for filtering in [lambda l: len(l) == full, lambda l: l.startswith(label), lambda l: not prefix_unique]:
+        filters = [lambda lbl: len(lbl) == len(label), lambda lbl: lbl.startswith(label), lambda lbl: not prefix_unique]
+        for filtering in filters:
             try:
                 found = next(label for label in compatible_labels if filtering(label))
             except StopIteration:
