@@ -344,16 +344,16 @@ class Media(object):
         """
         if media_id in self._media_overlays:
             c, p = self._media_overlays[media_id]
-            if c.is_shown(): c.do_hide()
-            if p.is_shown(): p.do_hide()
+            if c.is_shown(): GLib.idle_add(c.do_hide)
+            if p.is_shown(): GLib.idle_add(p.do_hide)
 
 
     def hide_all(self):
         """ Stops all playing medias and hides the players. Used before exit.
         """
         for c, p in self._media_overlays.values():
-            if c.is_shown(): c.do_hide()
-            if p.is_shown(): p.do_hide()
+            if c.is_shown(): GLib.idle_add(c.do_hide)
+            if p.is_shown(): GLib.idle_add(p.do_hide)
 
 
     def play_pause(self, media_id, gaction=None, param=None):
