@@ -41,7 +41,7 @@ class GifOverlay(base.VideoOverlay):
     #: A :class:`~GdkPixbuf.PixbufAnimation` containing all the frames and their timing for the displayed gif
     anim = None
     #: A :class:`~GdkPixbuf.PixbufAnimationIter` which will provide the timely access to the frames in `~anim`
-    iter = None
+    anim_iter = None
     #: A `tuple` of (`int`, `int`) indicating the size of the bounding box of the gif
     base_size = None
     #: The :class:`~cairo.Matrix` defining the zoom & shift to scale the gif
@@ -59,7 +59,7 @@ class GifOverlay(base.VideoOverlay):
         self.movie_zone.connect('configure-event', self.set_transform)
 
 
-    def set_file(self, filepath):
+    def _set_file(self, filepath):
         """ Sets the media file to be played by the widget.
 
         Args:
@@ -67,7 +67,7 @@ class GifOverlay(base.VideoOverlay):
         """
         self.anim = GdkPixbuf.PixbufAnimation.new_from_file(str(filepath))
         self.base_size = (self.anim.get_width(), self.anim.get_height())
-        self.iter = self.anim.get_iter(None)
+        self.anim_iter = self.anim.get_iter(None)
 
         self.set_transform()
         self.advance_gif()
@@ -87,12 +87,12 @@ class GifOverlay(base.VideoOverlay):
     def draw(self, widget, ctx):
         """ Simple resized drawing: get the pixbuf, set the transform, draw the image.
         """
-        if self.iter is None:
+        if self.anim_iter is None:
             return False
 
         try:
             ctx.transform(self.transform)
-            Gdk.cairo_set_source_pixbuf(ctx, self.iter.get_pixbuf(), 0, 0)
+            Gdk.cairo_set_source_pixbuf(ctx, self.anim_iter.get_pixbuf(), 0, 0)
             ctx.paint()
         except cairo.Error:
             logger.error(_('Cairo can not draw gif'), exc_info = True)
@@ -101,10 +101,10 @@ class GifOverlay(base.VideoOverlay):
     def advance_gif(self):
         """ Advance the gif, queue redrawing if the frame changed, and schedule the next frame.
         """
-        if self.iter.advance():
+        if self.anim_iter.advance():
             self.movie_zone.queue_draw()
 
-        delay = self.iter.get_delay_time()
+        delay = self.anim_iter.get_delay_time()
         if delay >= 0:
             GLib.timeout_add(delay, self.advance_gif)
 
@@ -112,7 +112,7 @@ class GifOverlay(base.VideoOverlay):
     def do_set_time(self, t):
         """ Set the player at time t.
 
-        Should run on the main thread to ensure we avoid vlc plugins' reentrency problems.
+        Should run on the main thread to ensure we avoid reentrency problems.
 
         Args:
             t (`int`): the timestamp, in ms
@@ -123,7 +123,7 @@ class GifOverlay(base.VideoOverlay):
         start = GLib.TimeVal()
         GLib.DateTime.new_now_local().to_timeval(start)
         start.add(-t)
-        self.iter = self.anim.get_iter(start)
+        self.anim_iter = self.anim.get_iter(start)
         self.advance_gif()
         return False
 
