@@ -27,11 +27,12 @@ import logging
 logger = logging.getLogger(__name__)
 
 import gi
-gi.require_version('Gtk', '3.0')
 gi.require_version('Gst', '1.0')
+gi.require_version('Gtk', '3.0')
 from gi.repository import GLib, Gst
 
 
+from pympress import util
 from pympress.media_overlays import base
 
 
@@ -43,6 +44,11 @@ class GstOverlay(base.VideoOverlay):
 
     #: A :class:`~Gst.Playbin` to be play videos
     playbin = None
+    #: A :class:`~Gst.Base.Sink` to display video content
+    sink = None
+
+    #: `int` number of milliseconds between updates
+    update_freq = 200
 
     def __init__(self, *args, **kwargs):
         # Create GStreamer playbin
@@ -63,7 +69,7 @@ class GstOverlay(base.VideoOverlay):
         bus.enable_sync_message_emission()
         bus.connect('message::eos', lambda *args: GLib.idle_add(self.handle_end))
         bus.connect('message::error', lambda _, msg: logger.error('{} {}'.format(*msg.parse_error())))
-        bus.connect('message::async-done', self.on_play)
+        bus.connect('message::state-changed', self.on_state_changed)
         bus.connect('message::duration-changed', lambda *args: GLib.idle_add(self.do_update_duration))
 
 
@@ -76,7 +82,7 @@ class GstOverlay(base.VideoOverlay):
         return self.playbin.get_state(0).state == Gst.State.PLAYING
 
 
-    def set_file(self, filepath):
+    def _set_file(self, filepath):
         """ Sets the media file to be played by the widget.
 
         Args:
@@ -92,16 +98,45 @@ class GstOverlay(base.VideoOverlay):
         Args:
             value (`bool`): `True` iff this player should be muted
         """
-        self.playbin.set_property('mute', value)
+        flags = self.playbin.get_property('flags')
+        # Fall back to the documented value if introspection fails,
+        # see https://gstreamer.freedesktop.org/documentation/playback/playsink.html?gi-language=python#GstPlayFlags
+        audio_flag = util.introspect_flag_value(type(flags), 'audio', 0x02)
+        if value:
+            flags = flags & ~audio_flag
+        else:
+            flags = flags | audio_flag
+        self.playbin.set_property('flags', flags)
         return False
 
 
-    def on_play(self, *args):
-        """ Start the scroll bar updating process.
+    def on_state_changed(self, bus, msg):
+        """ Callback triggered by playbin state changes.
+
+        Args:
+            bus (:class:`~Gst.Bus`): the bus that we are connected to
+            msg (:class:`~Gst.Message`): the "state-changed" message
         """
+        if msg.src != self.playbin:
+            # ignore the playbin's children
+            return
+        old, new, pending = msg.parse_state_changed()
+        if old == Gst.State.READY and new == Gst.State.PAUSED:
+            # the playbin goes from READY (= stopped) to PLAYING (via PAUSED)
+            self.on_initial_play()
+
+
+    def on_initial_play(self):
+        """ Set starting position, start scrollbar updates, unhide overlay. """
+        # set starting position, if needed
+        if self.start_pos:
+            self.do_set_time(self.start_pos)
+        # ensure the scroll bar is updated
         GLib.idle_add(self.do_update_duration)
-        GLib.timeout_add(200, self.do_update_time)
-        self.sink.props.widget.show()
+        GLib.timeout_add(self.update_freq, self.do_update_time)
+        # ensure the overlay is visible (if needed)
+        if not self.media_type.startswith('audio'):
+            self.sink.props.widget.show()
 
 
     def do_update_duration(self, *args):
@@ -112,14 +147,18 @@ class GstOverlay(base.VideoOverlay):
 
 
     def do_update_time(self):
-        """ Start playing the media file.
+        """ Update the current position in the progress bar.
 
         Returns:
-            `bool`: `True` iff this function should be run again (:func:`~GLib.idle_add` convention)
+            `bool`: `True` iff this function should be run again (:func:`~GLib.timeout_add` convention)
         """
         changed, time_ns = self.playbin.query_position(Gst.Format.TIME)
-        self.update_progress(time_ns / 1e9)
-        return True
+        time = time_ns / 1e9
+        self.update_progress(time)
+        if self.last_timestamp <= self.end_pos <= time:
+            self.handle_end()
+        self.last_timestamp = time
+        return self.playbin.get_state(0).state in {Gst.State.PLAYING, Gst.State.PAUSED}
 
 
     def do_play(self):
@@ -136,7 +175,7 @@ class GstOverlay(base.VideoOverlay):
     def do_play_pause(self):
         """ Toggle pause mode of the media.
 
-        Should run on the main thread to ensure we avoid vlc plugins' reentrency problems.
+        Should run on the main thread to ensure we avoid reentrency problems.
 
         Returns:
             `bool`: `True` iff this function should be run again (:func:`~GLib.idle_add` convention)
@@ -156,18 +195,19 @@ class GstOverlay(base.VideoOverlay):
         return False
 
 
-    def do_set_time(self, t):
-        """ Set the player at time t.
+    def do_set_time(self, time):
+        """ Set the player at time `~time`.
 
-        Should run on the main thread to ensure we avoid vlc plugins' reentrency problems.
+        Should run on the main thread to ensure we avoid reentrency problems.
 
         Args:
-            t (`float`): the timestamp, in s
+            time (`float`): the timestamp, in s
 
         Returns:
             `bool`: `True` iff this function should be run again (:func:`~GLib.idle_add` convention)
         """
-        self.playbin.seek_simple(Gst.Format.TIME, Gst.SeekFlags.FLUSH, t * Gst.SECOND)
+        self.last_timestamp = time
+        self.playbin.seek_simple(Gst.Format.TIME, Gst.SeekFlags.FLUSH, time * Gst.SECOND)
         return False
 
 
