@@ -708,9 +708,9 @@ class UI(builder.Builder):
             widget (:class:`~Gtk.Widget`):  the widget in which the event occurred (ignored)
             evt (:class:`~Gdk.Event`):  the event that occurred
         """
-        if type(evt) == Gdk.EventButton and evt.type == Gdk.EventType.BUTTON_RELEASE:
+        if isinstance(evt, Gdk.EventButton) and evt.type == Gdk.EventType.BUTTON_RELEASE:
             self.redraw_panes()
-        elif type(evt) == GObject.GParamSpec and evt.name == "position":
+        elif isinstance(evt, GObject.GParamSpec) and evt.name == "position":
             self.resize_panes = True
             if self.redraw_timeout:
                 GLib.Source.remove(self.redraw_timeout)
@@ -747,7 +747,6 @@ class UI(builder.Builder):
         about.set_comments(_('pympress is a little PDF reader written in Python ' +
                              'using Poppler for PDF rendering and GTK for the GUI.\n') +
                            _('Some preferences are saved in ') + str(self.config.path_to_config()) + '\n' +
-                           _('Resources are loaded from ') + str(util.get_locale_dir().parent) + '\n' +
                            _('The log is written to ') + str(util.get_log_path()) + '\n\n' +
                            _('Media support uses {}.').format(self.medias.backend_version) + '\n' +
                            _('Python version {}').format(sys.version))
